# DBLP

## search

### API search

Run a search on dblp.org and paste the url in the following command:

```
colrev search -a colrev.dblp -p "https://dblp.org/search?q=microsourcing"
```

### TOC search

TODO

## prep

linking metadata

## Links

- License: [Open Data Commons ODC-BY 1.0 license](https://dblp.org/db/about/copyright.html)
- [DBLP](https://dblp.org/)
